@@ -20,6 +20,8 @@ import os
 import uuid
 from typing import Any, Dict, List, Tuple, NamedTuple, Union, Optional, TYPE_CHECKING
 from xml.etree.ElementTree import Element, SubElement, ElementTree
+import defusedxml.ElementTree as Et  # type: ignore
+import xmltodict  # type: ignore
 
 from .util.color_generation import ColorGenerator
 
@@ -97,9 +99,9 @@ class _ModelMetadata(NamedTuple):
     model_id: str
     post_processing: Optional[str] = None
 
-    @classmethod
-    def from_json(cls, model_metadata: Union[str, Dict]) -> "ModelMetadata":
-        """This function parses a model specification JSON file to a ModelMetadata object.
+    @staticmethod
+    def from_json(model_metadata: Union[str, Dict]) -> "ModelMetadata":
+        """This function parses a model specification JSON file or dict loaded from it to a ModelMetadata object.
 
         Args:
             model_metadata: The path to the JSON file containing the model specification.
@@ -114,7 +116,6 @@ class _ModelMetadata(NamedTuple):
                 spec = json.load(f)
         else:
             spec = model_metadata
-
         return ModelMetadata(
             name=os.path.basename(spec.get("ModelPath", "DNN model")),
             color_handling=spec["ColorHandling"],
@@ -123,7 +124,7 @@ class _ModelMetadata(NamedTuple):
             border_size=spec["BorderSize"],
         )
 
-    def to_xml(self) -> ElementTree:
+    def to_xml(self) -> Et:
         """Creates an XML representation of the model meta data."""
         # Create root node
         model_node = Element("Model")
@@ -170,6 +171,31 @@ class _ModelMetadata(NamedTuple):
 
         return ElementTree(model_node)
 
+    @staticmethod
+    def from_xml(model_metadata: Union[str, Dict]) -> "ModelMetadata":
+        """This function parses a model specification XML file to a ModelMetadata object.
+
+        Args:
+            model_metadata: The path to the XML file containing the model specification.
+
+        Returns:
+            A ModelMetadata instance carrying all information to generate a CZModel file.
+        """
+        spec: Dict
+        # Load spec from json if necessary
+        if isinstance(model_metadata, str):
+            spec = xmltodict.parse(Et.tostring(Et.parse(model_metadata).getroot()))
+        else:
+            spec = model_metadata
+        spec = spec["Model"]
+        return ModelMetadata(
+            name=os.path.basename(spec.get("ModelPath", "DNN model")),
+            color_handling=spec["ColorHandling"],
+            pixel_types=spec["Channels"]["Item"]["@PixelType"],
+            classes=[item["@Name"] for item in spec["TrainingClasses"]["Item"]],
+            border_size=spec["BorderSize"],
+        )
+
 
 class ModelMetadata(_ModelMetadata):
     """Class representing the metadata of a model.
@@ -243,8 +269,8 @@ class ModelSpec(NamedTuple):
     model_metadata: ModelMetadata
     license_file: Optional[str] = None
 
-    @classmethod
-    def from_json(cls, model_spec_path: str) -> "ModelSpec":
+    @staticmethod
+    def from_json(model_spec_path: str) -> "ModelSpec":
         """This function parses a model specification JSON file to a ModelSpec object.
 
         Args:
